summaryrefslogtreecommitdiff
path: root/nuttx/arch/arm/src/kinetis
diff options
context:
space:
mode:
authorGregory Nutt <gnutt@nuttx.org>2013-07-26 10:09:17 -0600
committerGregory Nutt <gnutt@nuttx.org>2013-07-26 10:09:17 -0600
commitddb019413f39bbe495dba2a55c60f9ff8f8e00ce (patch)
tree9637f5cb852af32d6a500699ac6c16b25342dd8c /nuttx/arch/arm/src/kinetis
parent1e3a335beb36c0e88d75e449759d4fc54f4e299e (diff)
downloadnuttx-ddb019413f39bbe495dba2a55c60f9ff8f8e00ce.tar.gz
nuttx-ddb019413f39bbe495dba2a55c60f9ff8f8e00ce.tar.bz2
nuttx-ddb019413f39bbe495dba2a55c60f9ff8f8e00ce.zip
Finally... renamed all CONFIG_DRAM_ settings to CONFIG_RAM_
Diffstat (limited to 'nuttx/arch/arm/src/kinetis')
-rw-r--r--nuttx/arch/arm/src/kinetis/kinetis_allocateheap.c22
1 files changed, 11 insertions, 11 deletions
diff --git a/nuttx/arch/arm/src/kinetis/kinetis_allocateheap.c b/nuttx/arch/arm/src/kinetis/kinetis_allocateheap.c
index 8984217c7..8f9379f0f 100644
--- a/nuttx/arch/arm/src/kinetis/kinetis_allocateheap.c
+++ b/nuttx/arch/arm/src/kinetis/kinetis_allocateheap.c
@@ -112,21 +112,21 @@ void up_allocate_heap(FAR void **heap_start, size_t *heap_size)
*/
uintptr_t ubase = (uintptr_t)USERSPACE->us_bssend + CONFIG_MM_KERNEL_HEAPSIZE;
- size_t usize = CONFIG_DRAM_END - ubase;
+ size_t usize = CONFIG_RAM_END - ubase;
int log2;
- DEBUGASSERT(ubase < (uintptr_t)CONFIG_DRAM_END);
+ DEBUGASSERT(ubase < (uintptr_t)CONFIG_RAM_END);
/* Adjust that size to account for MPU alignment requirements.
* NOTE that there is an implicit assumption that the CONFIG_DRAM_END
* is aligned to the MPU requirement.
*/
log2 = (int)mpu_log2regionfloor(usize);
- DEBUGASSERT((CONFIG_DRAM_END & ((1 << log2) - 1)) == 0);
+ DEBUGASSERT((CONFIG_RAM_END & ((1 << log2) - 1)) == 0);
usize = (1 << log2);
- ubase = CONFIG_DRAM_END - usize;
+ ubase = CONFIG_RAM_END - usize;
/* Return the user-space heap settings */
@@ -143,7 +143,7 @@ void up_allocate_heap(FAR void **heap_start, size_t *heap_size)
up_ledon(LED_HEAPALLOCATE);
*heap_start = (FAR void*)g_idle_topstack;
- *heap_size = CONFIG_DRAM_END - g_idle_topstack;
+ *heap_size = CONFIG_RAM_END - g_idle_topstack;
#endif
}
@@ -166,21 +166,21 @@ void up_allocate_kheap(FAR void **heap_start, size_t *heap_size)
*/
uintptr_t ubase = (uintptr_t)USERSPACE->us_bssend + CONFIG_MM_KERNEL_HEAPSIZE;
- size_t usize = CONFIG_DRAM_END - ubase;
+ size_t usize = CONFIG_RAM_END - ubase;
int log2;
- DEBUGASSERT(ubase < (uintptr_t)CONFIG_DRAM_END);
+ DEBUGASSERT(ubase < (uintptr_t)CONFIG_RAM_END);
/* Adjust that size to account for MPU alignment requirements.
* NOTE that there is an implicit assumption that the CONFIG_DRAM_END
* is aligned to the MPU requirement.
*/
log2 = (int)mpu_log2regionfloor(usize);
- DEBUGASSERT((CONFIG_DRAM_END & ((1 << log2) - 1)) == 0);
+ DEBUGASSERT((CONFIG_RAM_END & ((1 << log2) - 1)) == 0);
usize = (1 << log2);
- ubase = CONFIG_DRAM_END - usize;
+ ubase = CONFIG_RAM_END - usize;
/* Return the kernel heap settings (i.e., the part of the heap region
* that was not dedicated to the user heap).
@@ -112,21 +112,21 @@ void up_allocate_heap(FAR void **heap_start, size_t *heap_size)
/* Adjust that size to account for MPU alignment requirements.
- * NOTE that there is an implicit assumption that the CONFIG_DRAM_END
+ * NOTE that there is an implicit assumption that the CONFIG_RAM_END
* is aligned to the MPU requirement.
*/
@@ -166,21 +166,21 @@ void up_allocate_kheap(FAR void **heap_start, size_t *heap_size)
/* Adjust that size to account for MPU alignment requirements.
- * NOTE that there is an implicit assumption that the CONFIG_DRAM_END
+ * NOTE that there is an implicit assumption that the CONFIG_RAM_END
* is aligned to the MPU requirement.
*/